#!/usr/bin/env node
import mri from 'mri';
import { resolve } from 'pathe';
import { buildModule } from './index.mjs';
import 'fs';
import 'url';
import 'consola';
import 'mlly';

async function prepareModule(options) {
  const { runCommand } = await import('nuxi');
  return runCommand("prepare", [options.rootDir], {
    overrides: {
      typescript: {
        builder: "shared"
      },
      imports: {
        autoImport: false
      },
      modules: [
        resolve(options.rootDir, "./src/module"),
        function(_options, nuxt) {
          nuxt.hooks.hook("app:templates", (app) => {
            for (const template of app.templates) {
              template.write = true;
            }
          });
        }
      ]
    }
  });
}

function main() {
  const args = mri(process.argv.slice(2));
  if (args._[0] === "prepare") {
    return prepareModule({
      rootDir: resolve(args._[1] || ".")
    });
  }
  return buildModule({
    rootDir: resolve(args._[0] || "."),
    outDir: args.outDir,
    stub: args.stub
  });
}
main().catch((err) => {
  console.error(err);
  process.exit(1);
});
